Test_avl: An remodified Available Function for testing the R Package...

Description Usage Arguments Value Examples

View source: R/Test_avl.R

Description

This function allows us to express availability of names, validity, whether Available on CRAN, whether Available on Bioconductor, whether Available on GitHub, etc.

Usage

1
Test_avl(variable)

Arguments

variable

The package name you want to check whether available or not. It uses the function (available) from the R package "available"

Value

Valid/Invalid List

Examples

1
2
3
Test_avl("a")
Test_avl("ABCD")
Test_avl("MASS")

debashischatterjee111/Bligom documentation built on Dec. 31, 2020, 11:15 p.m.