Description Usage Arguments Value Examples
This function allows us to express availability of names, validity, whether Available on CRAN, whether Available on Bioconductor, whether Available on GitHub, etc.
1 | Test_avl(variable)
|
variable |
The package name you want to check whether available or not. It uses the function (available) from the R package "available" |
Valid/Invalid List
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.